@@ -1,16 +1,12 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
+from __future__ import division
 from numpy import array
+import numpy
+from numpy.linalg import norm
+from pylab import *
 
-# Special points in FCC lattice
-G1=[0,0,0]
-G2=[1,1,1]
-L=[1/2.0,1/2.0,1/2.0]
-W=[1,1./2,3./2]
-X=[0,0,1]
-XP=[1,1,0]
-qpath=array([G1,X,G2,L])
 
 def get_EOS(d, comment=""):
     # Fitting functions
@@ -60,28 +56,23 @@ def get_EOS(d, comment=""):
     return fit, pv
 
 
-def analize_dir(idx, ex=True, bdir='/home/jochym/Desktop/Fizyka/', 
-                qp=array([G1,X,G2,L]), lbl=None, ax=None, castep=False):
+def plot_phonons(freq=None, dos=None, 
+                    qpath=array([]), qpname=[], 
+                    exper=None, ax=None, label=None, **kwargs):
+
+#idx, ex=True, bdir='/home/jochym/Desktop/Fizyka/', qp=array([G1,X,G2,L]), lbl=None, ax=None, castep=False):
     s=0
     t=[]
-    for x in [0]+map(norm,qp[1:]-qp[:-1]):
+    for x in [0]+map(norm,qpath[1:]-qpath[:-1]):
         s+=x
         t.append(s)
     
-    par=calcData[idx]
-    
-    try:
-        frq=loadtxt(bdir + idx +'/'+par['prefix']+'.freq.gp')
-    except IOError :
-        print "Cannot open frequency file in", wd
-        return
     if ax :
         ax1=ax[0]
     else :
         ax1=subplot2grid([1,4],[0,3],colspan=1)
     
-    phdos=loadtxt(bdir+idx+'/'+params['prefix']+'.dos')
-    clr=ax1.plot(phdos[:,1],cminv2meV*phdos[:,0])[0].get_color()
+    clr=ax1.plot( dos[1], dos[0])[0].get_color()
     ax1.yaxis.set_label_position("right")
     ax1.yaxis.tick_right()
     ax1.xaxis.tick_top()
@@ -90,40 +81,26 @@ def analize_dir(idx, ex=True, bdir='/home/jochym/Desktop/Fizyka/',
         ax2=ax[1]
     else :
         ax2=subplot2grid([1,4],[0,0],colspan=3,sharey=ax1)
-
     
     clr=None
     
-    if lbl :
-        lbltxt=", ".join(["%s" % (l,) for l in lbl if not (l in par.keys())])
-        lbltxt+=", ".join(["%s" % (par[l],) for l in lbl if l in par.keys()])
-    else :
-        lbltxt=idx    
-    
-    for i in range(frq.shape[1]-1):
+    for i in range(freq.shape[0]-1):
         if clr :
-            ax2.plot(frq[1:,0], cminv2meV*frq[1:,i+1],'.',color=clr)
+            ax2.plot(freq[0,1:], freq[i+1,1:],'.',color=clr)
         else :
-            clr=ax2.plot(frq[1:,0], cminv2meV*frq[1:,i+1],'.',label=lbltxt)[0].get_color()
+            clr=ax2.plot(freq[0,1:], freq[i+1,1:],'.',label=label)[0].get_color()
         
         
-    if ex :
-        frqexp1=loadtxt('thO2-phon.png.dat')
-        clr=ax2.plot(frqexp1[:,0],frqexp1[:,1],'o')[0].get_color();
-        frqexp2=loadtxt('thO2-phon-2.dat')
-        ax2.plot(t[2]-frqexp2[:,0],frqexp2[:,1],'o',color=clr)[0];
-        frqexp3=loadtxt('thO2-phon-3.dat')
-        ax2.plot(t[2]+frqexp3[:,0],frqexp3[:,1],'o',color=clr,label='Experiment')[0];
-    if castep :
-        frqexp4=loadtxt('castep-take2.csv')
-        ax2.plot((t[3]-t[0])*frqexp4[:,0], frqexp4[:,1],'o', label='CASTEP')
+    if exper :
+        clr=ax2.plot(exper[0],exper[1],'o',label='Experiment')[0].get_color();
 
-        
-    title("M-P grid (e.s.): %(kx)dx%(ky)dx%(kz)d (phon): %(nq)d^3" % par)
-    xlim(0,max(frq[1:,0]))
+    
+    xlim(0,max(freq[0,1:]))
     ylim(0,ylim()[1])
-    #xticks(t,[u'Γ','X',u'Γ','L'])
-    vlines(xticks()[0][1:-1],ylim()[0],ylim()[1],linestyles='--')
-    ylabel('Energy (meV)')
+    if qpname :
+        #print t, qpname, min(freq[0]), max(freq[0])
+        xticks(t,qpname)
+        vlines(xticks()[0][1:-1],ylim()[0],ylim()[1],linestyles='--')
+        
     subplots_adjust(wspace=0)
     return [ax1,ax2]
